package com.school.project.service.teacher;

import com.school.project.dto.PaginationDTO;
import com.school.project.dto.teacher.TeacherViewCoursesDTO;
import com.school.project.dto.teacher.TeacherViewDataDTO;
import com.school.project.mapper.PageOfTeacherToDTO;
import com.school.project.mapper.TeacherViewCoursesMapper;
import com.school.project.mapper.TeacherViewDataMapper;
import com.school.project.model.Teacher;
import com.school.project.model.userRegistration.User;
import com.school.project.repository.*;
import com.school.project.repository.userRegistration.UserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.stereotype.Service;

@Service
public class TeacherServiceImpl implements TeacherService {

    @Autowired
    TeacherRepository teacherRepository;

    @Autowired
    UserRepository userRepository;

    @Autowired
    TeacherViewDataMapper teacherViewDataMapper;

    @Autowired
    TeacherViewCoursesMapper teacherViewCoursesMapper;


    private PageOfTeacherToDTO pageOfTeacherToDTO;


    @Override
    public TeacherViewDataDTO getTeacherData(String username) {

        User user = userRepository.findUserByEmail(username).get();

        return teacherViewDataMapper.modelToDto(
                teacherRepository.findOneByTeacherId(user.getUserId()));
    }

    @Override
    public TeacherViewCoursesDTO getTeacherCourses(String username) {
        User user = userRepository.findUserByEmail(username).get();

        return teacherViewCoursesMapper.modelToDTO(
                teacherRepository.findOneByTeacherId(user.getUserId()));
    }

    public Page<TeacherViewDataDTO> getAllTeachers(PaginationDTO paginationDTO) {

        return pageOfTeacherToDTO.modelToDTO(teacherRepository.findAll(PageRequest.of(paginationDTO.getPage(), paginationDTO.getSize())));
    }

    @Autowired
    public void setPageOfTeacherToDTO(PageOfTeacherToDTO pageOfTeacherToDTO) {
        this.pageOfTeacherToDTO = pageOfTeacherToDTO;
    }
}
